Crate zigbee_core

Crate zigbee_core 

Implements the Zigbee protocol stack in no-std based on the Zigbee Specification R23

This crate contains the core network layer and security features. It deals with addressing, keys, trust center, formation and discovery mechanisms.

Re-exports

pub use apl::descriptors::node_descriptor::LogicalType;
pub use apl::descriptors::node_power_descriptor::CurrentPowerMode;
pub use apl::descriptors::node_power_descriptor::CurrentPowerSourceLevel;
pub use apl::descriptors::node_power_descriptor::PowerSource;

Modules

apl
Application Framework
aps
Application Support Sub-Layer
nwk
Network Layer
security
Security Service
storage
Persistent storage for the information bases.
zdp
Zigbee Device Profile (2.4). Device Profile

Structs

Config
zigbee configuration