Module apsme

Module apsme 

The APS management entity provides a variety of services to application objects including security services and binding of devices. It also maintains a database of managed objects, known as the APS information base (AIB). Application Support Sub-Layer Management Entity

The APSME shall provide a management service to allow an application to interact with the stack.

It provides the following services:

  • Binding management
  • AIB management
  • Security
  • Group management

Modules

basemgt
APSME primitive types for binding, group management, and AIB access (2.2.4.3 - 2.2.4.5).
groupmgt
Group Management

Traits

ApsmeSap
Application support sub-layer management service - service access point