Network Layer
The network layer is required to provide functionality to ensure correct operation of the IEEE 802.15.4 MAC sub-layer and to provide a suitable service interface to the application layer.
Network Layer
The network layer is required to provide functionality to ensure correct operation of the IEEE 802.15.4 MAC sub-layer and to provide a suitable service interface to the application layer.