Module client_services

Module client_services 

Client Services

The Device Profile Client Services support the transport of device and service discovery requests, end device binding requests, bind requests, unbind requests, and network management requests from client to server. Additionally, Client Services support receipt of responses to these requests from the server.

Modules

discovery