Application Support Sub-Layer
See Section 2.2
The application support sub-layer provides an interface between the
Network layer and the Application layer.
Modules
- aib
- apsde
- The APS data entity provides the data transmission service between two or more application entities located on the same network. Application Support Sub-Layer Data Entity
- apsme
- The APS management entity provides a variety of services to application objects including security services and binding of devices. It also maintains a database of managed objects, known as the APS information base (AIB). Application Support Sub-Layer Management Entity
- binding
- Binding table (2.2.8.2.1). Binding table (2.2.8.2.1).
- frame
- APS frame formats (2.2.5).
- security
- APS layer security services (4.4)
- types