#[repr(usize)]pub enum AibId {
Show 16 variants
binding_table = 0,
designated_coordinator = 1,
channel_mask_list = 2,
use_extended_pan_id = 3,
group_table = 4,
non_member_radius = 5,
use_insecure_join = 6,
interframe_delay = 7,
last_channel_energy = 8,
last_channel_failure_rate = 9,
channel_timer = 10,
max_window_size = 11,
parent_announce_timer = 12,
device_key_pair_set = 13,
trust_center_address = 14,
security_timeout_period = 15,
}Variants
binding_table = 0
designated_coordinator = 1
channel_mask_list = 2
use_extended_pan_id = 3
group_table = 4
non_member_radius = 5
use_insecure_join = 6
interframe_delay = 7
last_channel_energy = 8
last_channel_failure_rate = 9
channel_timer = 10
max_window_size = 11
parent_announce_timer = 12
device_key_pair_set = 13
trust_center_address = 14
security_timeout_period = 15
Implementations
Sourceimpl AibId
impl AibId
Sourcepub const MAX_FIELD_SIZE: usize
pub const MAX_FIELD_SIZE: usize
Upper bound of the encoded size over all persisted fields.
Sourcepub const fn storage_key(&self) -> Option<u8>
pub const fn storage_key(&self) -> Option<u8>
Returns the stable persistence key, or None for RAM-only fields.
Sourcepub const fn from_storage_key(key: u8) -> Option<Self>
pub const fn from_storage_key(key: u8) -> Option<Self>
Resolves a stable persistence key back to its field id.